// Simple auth utilities for the demo application

export interface User {
  id: string;
  name: string;
  email: string;
  role: string;
}

export interface DecodedToken {
  id: string;
  name: string; // Added name property to match usage
  email: string;
  role: string;
  parentsEveningId?: string;
  exp: number;
}

export function decodeToken(token: string): DecodedToken | null {
  try {
    const decoded = JSON.parse(Buffer.from(token, 'base64').toString());
    
    // Check if token is expired
    if (decoded.exp && decoded.exp < Math.floor(Date.now() / 1000)) {
      return null;
    }
    
    return decoded;
  } catch (error) {
    console.error("Error decoding token:", error);
    return null;
  }
}

export function isTokenValid(token: string): boolean {
  return decodeToken(token) !== null;
}

export function getUserFromToken(token: string): User | null {
  const decoded = decodeToken(token);
  if (!decoded) return null;
  
  return {
    id: decoded.id,
    name: decoded.name || 'User',
    email: decoded.email,
    role: decoded.role,
  };
}